@@ -16,6 +16,7 @@ from neosctl import (
     profile,
     registry,
     schema,
+    source,
     spark,
     storage,
     util,
@@ -134,6 +135,7 @@ app.add_typer(iam.app, name="iam", callback=_common, help="Manage access policie
 app.add_typer(storage.app, name="storage", callback=_common, help="Interact with Storage (as a service).")
 app.add_typer(metadata.app, name="metadata", callback=_common, help="Manage and browse metadata.")
 app.add_typer(product.app, name="product", callback=_common, help="Manage data products.")
+app.add_typer(source.app, name="source", help="Manage sources.")
 app.add_typer(registry.app, name="registry", callback=_common, help="Manage cores and search data products.")
 app.add_typer(spark.app, name="spark", callback=_common, help="Manage data product spark/secrets.")
 app.add_typer(kafka.app, name="kafka", callback=_common, help="Manage data product kafka streaming.")
