@@ -1,8 +1,10 @@
 import json
+import mimetypes
 import pathlib
 import typing
 
 import httpx
+import jq
 import typer
 
 from neosctl import constant, schema, util
@@ -48,20 +50,21 @@ def template(
     """
 
     @ensure_login
-    def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
+    def _request(ctx: typer.Context, f: typing.IO, mime_type: typing.Optional[str]) -> httpx.Response:
         params = {k: v for k, v in [("delimiter", delimiter), ("quotechar", quotechar)] if v is not None}
 
         return util.post(
             ctx,
             f"{_product_url(ctx)}/template",
             params=params,
-            files={"csv_file": f},
+            files={"csv_file": ("upload.csv", f, mime_type)},
         )
 
     fp = util.get_file_location(filepath)
+    mime_type = mimetypes.guess_type(fp)
 
     with fp.open("rb") as f:
-        r = _request(ctx, f)
+        r = _request(ctx, f, mime_type[0])
 
     if r.status_code >= constant.BAD_REQUEST_CODE:
         process_response(r)
@@ -145,15 +148,48 @@ def add_schema(
 
 
 @app.command(name="list")
-def list_products(ctx: typer.Context) -> None:
-    """List data products."""
+def list_products(
+    ctx: typer.Context,
+    filter_: typing.Optional[str] = typer.Option(
+        None,
+        "--filter",
+        "-f",
+        help="jq filter to apply to data_products.",
+        callback=util.sanitize,
+    ),
+    name: typing.Optional[str] = typer.Option(
+        None,
+        "--name",
+        "-n",
+        help="Filter products for a specific name. (Overrides --filter if provided)",
+        callback=util.sanitize,
+    ),
+) -> None:
+    """List data products.
+
+    Provide a filter to access specific elements in the returned list.
+    """
 
     @ensure_login
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(ctx, _product_url(ctx))
 
+    if name:
+        filter_ = f'{{data_products: [.data_products[] | select(.name | contains("{name}"))]}}'
+
+    def _filter_products(payload: typing.Dict) -> str:
+        """Filter response with an optional jq filter."""
+        if filter_:
+            output = jq.compile(filter_).input(payload)
+            payload = output.all()
+            if name:
+                payload = output.first()
+
+        return util.prettify_json(payload)
+
     r = _request(ctx)
-    process_response(r)
+
+    process_response(r, _filter_products)  # type: ignore[reportGeneralTypeIssues]
 
 
 @app.command()
