@@ -1,3 +1,4 @@
+import mimetypes
 import typing
 
 import httpx
@@ -376,7 +377,7 @@ def csv_job(
     """
 
     @ensure_login
-    def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
+    def _request(ctx: typer.Context, f: typing.IO, mime_type: typing.Optional[str]) -> httpx.Response:
         params = {
             k: v
             for k, v in [
@@ -391,13 +392,14 @@ def csv_job(
             ctx,
             f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/csv",
             params=params,
-            files={"csv_file": f},
+            files={"csv_file": ("upload.csv", f, mime_type)},
         )
 
     fp = util.get_file_location(job_filepath)
+    mime_type = mimetypes.guess_type(fp)
 
     with fp.open("rb") as f:
-        r = _request(ctx, f)
+        r = _request(ctx, f, mime_type[0])
 
     process_response(r)
 
