@@ -9,6 +9,10 @@ from neosctl.util import process_response
 
 app = typer.Typer()
 
+bucket_app = typer.Typer()
+
+app.add_typer(bucket_app, name="bucket", help="Manage object buckets.")
+
 
 def _storage_url(ctx: typer.Context, postfix: str) -> str:
     return "{}/{}".format(ctx.obj.storage_api_url.rstrip("/"), postfix)
@@ -177,3 +181,57 @@ def fetchrow(
 ) -> None:
     """Fetch first result of a statement."""
     _handle(ctx, "fetchrow", statement, statement_filepath, params_filepath)
+
+
+@bucket_app.command(name="create")
+def create_bucket(
+    ctx: typer.Context,
+    bucket_name: typing.Optional[str] = typer.Option(
+        None,
+        "--bucket-name",
+        "-n",
+        help="Bucket name",
+        callback=util.sanitize,
+    ),
+) -> None:
+    """Create new bucket."""
+
+    @ensure_login
+    def _request(ctx: typer.Context, bucket_name: str) -> httpx.Response:
+        return util.put(ctx, url=_storage_url(ctx, f"objects/{bucket_name}"))
+
+    response = _request(ctx, bucket_name)
+    process_response(response)
+
+
+@bucket_app.command(name="list")
+def list_buckets(ctx: typer.Context) -> None:
+    """List buckets."""
+
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(ctx, url=_storage_url(ctx, "objects"))
+
+    response = _request(ctx)
+    process_response(response)
+
+
+@bucket_app.command(name="delete")
+def delete_bucket(
+    ctx: typer.Context,
+    bucket_name: typing.Optional[str] = typer.Option(
+        None,
+        "--bucket-name",
+        "-n",
+        help="Bucket name",
+        callback=util.sanitize,
+    ),
+) -> None:
+    """Delete bucket."""
+
+    @ensure_login
+    def _request(ctx: typer.Context, bucket_name: str) -> httpx.Response:
+        return util.delete(ctx, url=_storage_url(ctx, f"objects/{bucket_name}"))
+
+    response = _request(ctx, bucket_name)
+    process_response(response)
